@@ -3,7 +3,7 @@ BEGIN {
   $Dist::Zilla::Plugin::EOLTests::AUTHORITY = 'cpan:FLORA';
 }
 BEGIN {
-  $Dist::Zilla::Plugin::EOLTests::VERSION = '0.01';
+  $Dist::Zilla::Plugin::EOLTests::VERSION = '0.02';
 }
 # ABSTRACT: Release tests making sure correct line endings are used
 
@@ -11,8 +11,28 @@ use Moose;
 use namespace::autoclean;
 
 extends 'Dist::Zilla::Plugin::InlineFiles';
+with 'Dist::Zilla::Role::TextTemplate';
 
 
+has trailing_whitespace => (
+    is      => 'ro',
+    isa     => 'Bool',
+    default => 1,
+);
+
+around add_file => sub {
+    my ($orig, $self, $file) = @_;
+    return $self->$orig(
+        Dist::Zilla::File::InMemory->new({
+            name    => $file->name,
+            content => $self->fill_in_string(
+                $file->content,
+                { trailing_ws => \$self->trailing_whitespace },
+            ),
+        }),
+    );
+};
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -40,9 +60,17 @@ a standard Test::EOL test
 
 =back
 
+=head1 ATTRIBUTES
+
+=head2 trailing_whitespace
+
+If this option is set to a true value,
+C<< { trailing_whitespace => 1 } >> will be passed to
+L<Test::EOL/all_perl_files_ok>. It defaults to C<1>.
+
 =head1 AUTHOR
 
-  Florian Ragwitz <rafl@debian.org>
+Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -63,4 +91,4 @@ use Test::More;
 eval 'use Test::EOL';
 plan skip_all => 'Test::EOL required' if $@;
 
-all_perl_files_ok();
+all_perl_files_ok({ trailing_whitespace => {{ $trailing_ws }} });
